package com.iconplus.smartproc.repository;

import com.iconplus.smartproc.model.entity.Lokasi;
import com.iconplus.smartproc.model.projection.LokasiView;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.data.jpa.repository.JpaRepository;
import org.springframework.data.jpa.repository.Query;
import org.springframework.stereotype.Repository;

import java.util.List;
import java.util.Optional;

@Repository
public interface LokasiRepository extends JpaRepository<Lokasi, Long> {

    @Query(value = "SELECT l.id as id, " +
            "l.lokasi as lokasi, " +
            "l.keterangan as keterangan, " +
            "l.isActive as isActive, " +
            "l.isDelete as isDelete " +
            "FROM Lokasi l " +
            "WHERE l.isDelete = false " +
            "AND (:search = '' " +
            "or UPPER(l.lokasi) like :search) " +
            "ORDER BY l.id")
    Page<LokasiView> getAllLokasi(String search, Pageable pageable);

    Optional<Lokasi> findByIdAndIsDeleteFalse(Long id);

    Optional<Lokasi> findByLokasiAndIsDeleteFalse(String lokasi);

    @Query(value = "SELECT l " +
            "FROM Lokasi l " +
            "WHERE l.lokasi in (:lokasi) " +
            "AND l.isDelete = false")
    List<Lokasi> getListLokasi(List<String> lokasi);
    
}
