package com.iconplus.smartproc.service.rksdaftarisi;

import com.iconplus.smartproc.helper.model.Pagination;
import com.iconplus.smartproc.helper.service.BaseService;
import com.iconplus.smartproc.model.entity.RksDaftarIsi;
import com.iconplus.smartproc.model.request.RksDaftarIsiRequest;
import com.iconplus.smartproc.model.response.ListRksDaftarIsiResponse;
import com.iconplus.smartproc.model.response.RksDaftarIsiResponse;
import com.iconplus.smartproc.repository.RksDaftarIsiRepository;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

@Service
public class GetListRksIsiService implements BaseService<RksDaftarIsiRequest, ListRksDaftarIsiResponse> {

    private final RksDaftarIsiRepository rksDaftarIsiRepository;

    public GetListRksIsiService(RksDaftarIsiRepository rksDaftarIsiRepository) {
        this.rksDaftarIsiRepository = rksDaftarIsiRepository;
    }

    @Override
    public ListRksDaftarIsiResponse execute(RksDaftarIsiRequest input) {

        List<RksDaftarIsiResponse> rksDaftarIsiResponseList = new ArrayList<>();
        var rksIsis = rksDaftarIsiRepository.findByRksDaftarIdAndIsDeleteFalse(input.getRksDaftarId(), input.getPageable());
        for (RksDaftarIsi rksDaftarIsi : rksIsis) {
            RksDaftarIsiResponse rksDaftarIsiResponse = RksDaftarIsiResponse.builder()
                    .id(rksDaftarIsi.getId())
                    .rksDaftarId(rksDaftarIsi.getRksDaftarId())
                    .nomor(rksDaftarIsi.getNomor())
                    .parentId(rksDaftarIsi.getParentId())
                    .title(rksDaftarIsi.getTitle())
                    .level(rksDaftarIsi.getLevel())
                    .urutan(rksDaftarIsi.getUrutan())
                    .isKontrak(rksDaftarIsi.getIsKontrak())
                    .isActive(rksDaftarIsi.getIsActive())
                    .build();
            rksDaftarIsiResponseList.add(rksDaftarIsiResponse);
        }

        return ListRksDaftarIsiResponse.builder()
                .data(rksDaftarIsiResponseList)
                .pagination(Pagination.builder()
                        .pageSize(input.getPageable().getPageSize())
                        .currentPage(input.getPageable().getPageNumber())
                        .totalPages(rksIsis.getTotalPages())
                        .totalRecords(rksIsis.getTotalElements())
                        .isFirstPage(rksIsis.isFirst())
                        .isLastPage(rksIsis.isLast())
                        .build())
                .build();
    }
}
