package com.iconplus.smartproc.service.rksdaftarisi;

import com.iconplus.smartproc.exception.BusinessException;
import com.iconplus.smartproc.helper.service.BaseService;
import com.iconplus.smartproc.model.entity.RksDaftar;
import com.iconplus.smartproc.model.request.RksDaftarRequest;
import com.iconplus.smartproc.model.response.RksDaftarResponse;
import com.iconplus.smartproc.repository.RksDaftarRepository;
import com.iconplus.smartproc.util.Constants;
import org.springframework.stereotype.Service;

@Service
public class PostCreateRksDaftarIsiService implements BaseService<RksDaftarRequest, RksDaftarResponse> {

    private final RksDaftarRepository rksDaftarRepository;
    public PostCreateRksDaftarIsiService(RksDaftarRepository rksDaftarRepository) {
        this.rksDaftarRepository = rksDaftarRepository;
    }

    @Override
    public RksDaftarResponse execute(RksDaftarRequest input) {

        var rksDaftarIsiOptional = rksDaftarRepository.findByKodeTemplateAndIsDeleteFalse(input.getKodeTemplate());
        if (rksDaftarIsiOptional.isPresent()) {
            throw new BusinessException(Constants.ERR_CODE_10002,
                    Constants.ERR_TTL_10002,
                    String.format(Constants.ERR_MSG_10002, "RKS Kode Template", input.getKodeTemplate()));
        }


        RksDaftar rksDaftar = RksDaftar.builder()
                .kodeTemplate(input.getKodeTemplate())
                .namaTemplate(input.getNamaTemplate())
                .metodePengadaanId(input.getMetodePengadaanId())
                .versi(input.getVersi())
                .isDelete(false)
                .build();

        var result = rksDaftarRepository.save(rksDaftar);
        return RksDaftarResponse.builder()
                .id(result.getId())
                .build();
    }
}
